from os.path import isdir, dirname, isfile
from os import makedirs

import convertible
import models


class Applications:

    def __init__(self, filename):
        self.filename = filename

    def list(self):
        apps_data = convertible.read_json(self.filename, models.Apps)
        if not apps_data:
            return []
        return apps_data.apps


class Installations:

    def __init__(self, filename):
        self.filename = filename
        self.__create_folder(filename)

    def __create_folder(self, filename):
        path = dirname(filename)
        if not isdir(path):
            makedirs(path)

    def __read(self):
        versions = {}
        if isfile(self.filename):
            with open(self.filename, 'r') as f:
                lines = f.readlines()
                for line in lines:
                    id, version = line.strip().split('=', 1)
                    versions[id.strip()] = version.strip()
        return versions

    def __write(self, versions):
        with open(self.filename, 'w+') as f:
            for id, version in versions.iteritems():
                f.write('{}={}\n'.format(id, version))

    def version(self, app):
        versions = self.__read()
        return versions.get(app.id, None)

    def remove(self, app):
        versions = self.__read()
        del versions[app.id]
        self.__write(versions)

    def update(self, app, version):
        versions = self.__read()
        versions[app.id] = version
        self.__write(versions)
